TryFromPath

Trait TryFromPath 

pub trait TryFromPath {
    // Required method
    fn try_from_path(path: &Path) -> Result<Anchor, WasmError>;
}

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl TryFromPath for Anchor

Paths are more general than anchors so a path could be represented that is not a valid anchor. The obvious example would be a path of binary data that is not valid utf-8 strings or a path that is more than 2 levels deep.