GetLinksInputBuilder

Struct GetLinksInputBuilder 

pub struct GetLinksInputBuilder(/* private fields */);
A builder to streamline creating a GetLinksInput.

Example: Get links of any time from a given base address.

use hdk::prelude::*;

    let my_base = ActionHash::from_raw_36(vec![0; 36]); // Some base address, this is a dummy address created for the example!
    let links = get_links(LinkQuery::try_new(my_base, ..)?, GetStrategy::default())?;

Example: Get links of a specific type from a given base address.

use hdk::prelude::*;

#[hdk_link_types]
pub enum LinkTypes {
    Example,
}

    let my_base = ActionHash::from_raw_36(vec![0; 36]); // Some base address, this is a dummy address created for the example!
    let links = get_links(LinkQuery::try_new(my_base, LinkTypes::Example)?, GetStrategy::default())?;

You can add additional filters using the functions defined on the builder. For example, to only fetch links that are available locally, without going to the network:

use hdk::prelude::*;

    let my_base = ActionHash::from_raw_36(vec![0; 36]); // Some base address, this is a dummy address created for the example!
    let links = get_links(LinkQuery::try_new(my_base, ..)?, GetStrategy::Local)?;

Implementations

Source

impl GetLinksInputBuilder

pub fn try_new( base_address: impl Into<AnyLinkableHash>, link_type: impl LinkTypeFilterExt, ) -> Result<Self, WasmError>

Create a new GetLinksInputBuilder from the required fields for a GetLinksInput.

pub fn get_options(self, get_strategy: GetStrategy) -> Self

Fetch links from network or local only.

pub fn tag_prefix(self, tag_prefix: LinkTag) -> Self

Filter for links with the given tag prefix.

pub fn before(self, before: Timestamp) -> Self

Filter for links created before before.

pub fn after(self, after: Timestamp) -> Self

Filter for links create after after.

pub fn author(self, author: AgentPubKey) -> Self

Filter for links created by this author.

pub fn build(self) -> GetLinksInput

Construct the result of the builder.