pub enum EntryType {
AgentPubKey,
App(AppEntryDef),
CapClaim,
CapGrant,
}Expand description
Allows Actions which reference Entries to know what type of Entry it is referencing. Useful for examining Actions without needing to fetch the corresponding Entries.
Variants
AgentPubKey
An AgentPubKey
App(AppEntryDef)
An app-provided entry, along with its app-provided AppEntryDef
CapClaim
A Capability claim
CapGrant
A Capability grant.
Implementations
Sourceimpl EntryType
impl EntryType
pub fn visibility(&self) -> &EntryVisibility