pub enum ZomeDef {
Wasm(WasmZome),
}Expand description
Just the definition of a Zome, without the name included. This exists mainly for use in HashMaps where ZomeDefs are keyed by ZomeName.
NB: Only Wasm Zomes are valid to pass through round-trip serialization, because Rust functions are not serializable. Hence, this enum serializes as if it were a bare WasmZome, and when deserializing, only Wasm zomes can be produced. InlineZomes are serialized as their network seed, so that a hash can be computed, but it is invalid to attempt to deserialize them again.
In particular, a real-world DnaFile should only ever contain Wasm zomes!
Variants
Implementations