pub struct ClonedCell {
pub cell_id: CellId,
pub clone_id: CloneId,
pub original_dna_hash: HoloHash<Dna>,
pub dna_modifiers: DnaModifiers,
pub name: String,
pub enabled: bool,
}Expand description
Cloned cell that was created from a provisioned cell at runtime.
Fields
cell_id: CellIdThe cell’s identifying data
clone_id: CloneIdA conductor-local clone identifier
original_dna_hash: HoloHash<Dna>The hash of the DNA that this cell was instantiated from
dna_modifiers: DnaModifiersThe DNA modifiers that were used to instantiate this clone cell
name: StringThe name the cell was instantiated with
enabled: boolWhether or not the cell is running