pub struct Create<W = EntryRateWeight> {
pub author: HoloHash<Agent>,
pub timestamp: Timestamp,
pub action_seq: u32,
pub prev_action: HoloHash<Action>,
pub entry_type: EntryType,
pub entry_hash: HoloHash<Entry>,
pub weight: W,
}Expand description
An action which “speaks” Entry content into being. The same content can be referenced by multiple such actions.
Fields
timestamp: Timestampaction_seq: u32prev_action: HoloHash<Action>entry_type: EntryTypeentry_hash: HoloHash<Entry>weight: WTrait Implementations
Sourceimpl ActionUnweighed for Create<()>
impl ActionUnweighed for Create<()>
Sourceimpl ActionWeighed for Create
impl ActionWeighed for Create
type Unweighed = Create<()>
type Weight = EntryRateWeight
Sourcefn into_action(self) -> Action
fn into_action(self) -> Action
Construct the full Action enum with this variant.
Sourcefn unweighed(self) -> Create<()>
fn unweighed(self) -> Create<()>
Erase the rate limiting weight info, creating an “unweighed” version
of this action. This is used primarily by validators who need to run the
weigh callback on an action they received, and want to make sure their
callback is not using the predefined weight to influence the result.Sourceimpl<'de, W> Deserialize<'de> for Create<W>where
W: Deserialize<'de>,
impl<'de, W> Deserialize<'de> for Create<W>where
W: Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Create<W>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Create<W>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Create> for EntryCreationAction
impl From<Create> for EntryCreationAction
Sourcefn from(c: Create) -> EntryCreationAction
fn from(c: Create) -> EntryCreationAction
Converts to this type from the input type.
Sourceimpl HashableContent for Create
impl HashableContent for Create
Sourcefn hash_type(&self) -> <Create as HashableContent>::HashType
fn hash_type(&self) -> <Create as HashableContent>::HashType
The HashType which this content will be hashed to
Sourcefn hashable_content(&self) -> HashableContentBytes
fn hashable_content(&self) -> HashableContentBytes
Return a subset of the content, either as SerializedBytes “content”,
which will be used to compute the hash, or as an already precomputed
hash which will be used directly
Sourceimpl<W> Serialize for Create<W>where
W: Serialize,
impl<W> Serialize for Create<W>where
W: Serialize,
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<&Create> for SerializedBytes
impl TryFrom<&Create> for SerializedBytes
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(t: &Create) -> Result<SerializedBytes, SerializedBytesError>
fn try_from(t: &Create) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
Sourceimpl TryFrom<Create> for SerializedBytes
impl TryFrom<Create> for SerializedBytes
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(t: Create) -> Result<SerializedBytes, SerializedBytesError>
fn try_from(t: Create) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
Sourceimpl TryFrom<SerializedBytes> for Create
impl TryFrom<SerializedBytes> for Create
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(sb: SerializedBytes) -> Result<Create, SerializedBytesError>
fn try_from(sb: SerializedBytes) -> Result<Create, SerializedBytesError>
Performs the conversion.
impl<W> Eq for Create<W>where
W: Eq,
impl<W> StructuralPartialEq for Create<W>