pub struct DeleteLink {
pub author: HoloHash<Agent>,
pub timestamp: Timestamp,
pub action_seq: u32,
pub prev_action: HoloHash<Action>,
pub base_address: HoloHash<AnyLinkable>,
pub link_add_address: HoloHash<Action>,
}Expand description
Declares that a previously made Link should be nullified and considered removed.
Fields
timestamp: Timestampaction_seq: u32prev_action: HoloHash<Action>base_address: HoloHash<AnyLinkable>this is redundant with the CreateLink action but needs to be included to facilitate DHT ops
this is NOT exposed to wasm developers and is validated by the subconscious to ensure that
it always matches the base_address of the CreateLink
link_add_address: HoloHash<Action>The address of the CreateLink being reversed