pub struct EntryRateWeight {
pub bucket_id: u8,
pub units: u8,
pub rate_bytes: u8,
}Expand description
Combination of the three main rate limiting data types, for convenience
Fields
bucket_id: u8units: u8rate_bytes: u8Trait Implementations
Sourceimpl Clone for EntryRateWeight
impl Clone for EntryRateWeight
Sourcefn clone(&self) -> EntryRateWeight
fn clone(&self) -> EntryRateWeight
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EntryRateWeight
impl Debug for EntryRateWeight
Sourceimpl Default for EntryRateWeight
impl Default for EntryRateWeight
Sourcefn default() -> EntryRateWeight
fn default() -> EntryRateWeight
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EntryRateWeight
impl<'de> Deserialize<'de> for EntryRateWeight
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<EntryRateWeight, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<EntryRateWeight, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<EntryRateWeight> for RateWeight
impl From<EntryRateWeight> for RateWeight
Sourcefn from(w: EntryRateWeight) -> RateWeight
fn from(w: EntryRateWeight) -> RateWeight
Converts to this type from the input type.
Sourceimpl Hash for EntryRateWeight
impl Hash for EntryRateWeight
Sourceimpl Ord for EntryRateWeight
impl Ord for EntryRateWeight
Sourcefn cmp(&self, other: &EntryRateWeight) -> Ordering
fn cmp(&self, other: &EntryRateWeight) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EntryRateWeight
impl PartialEq for EntryRateWeight
Sourceimpl PartialOrd for EntryRateWeight
impl PartialOrd for EntryRateWeight
Sourceimpl Serialize for EntryRateWeight
impl Serialize for EntryRateWeight
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<&EntryRateWeight> for SerializedBytes
impl TryFrom<&EntryRateWeight> for SerializedBytes
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(
t: &EntryRateWeight,
) -> Result<SerializedBytes, SerializedBytesError>
fn try_from( t: &EntryRateWeight, ) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
Sourceimpl TryFrom<EntryRateWeight> for SerializedBytes
impl TryFrom<EntryRateWeight> for SerializedBytes
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(t: EntryRateWeight) -> Result<SerializedBytes, SerializedBytesError>
fn try_from(t: EntryRateWeight) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
Sourceimpl TryFrom<SerializedBytes> for EntryRateWeight
impl TryFrom<SerializedBytes> for EntryRateWeight
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(
sb: SerializedBytes,
) -> Result<EntryRateWeight, SerializedBytesError>
fn try_from( sb: SerializedBytes, ) -> Result<EntryRateWeight, SerializedBytesError>
Performs the conversion.
impl Eq for EntryRateWeight
impl StructuralPartialEq for EntryRateWeight