pub struct RateWeight {
pub bucket_id: u8,
pub units: u8,
}Expand description
Combination of two rate limiting data types, for convenience
Fields
bucket_id: u8units: u8Trait Implementations
Sourceimpl Clone for RateWeight
impl Clone for RateWeight
Sourcefn clone(&self) -> RateWeight
fn clone(&self) -> RateWeight
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateWeight
impl Debug for RateWeight
Sourceimpl Default for RateWeight
impl Default for RateWeight
Sourcefn default() -> RateWeight
fn default() -> RateWeight
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RateWeight
impl<'de> Deserialize<'de> for RateWeight
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RateWeight, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RateWeight, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<EntryRateWeight> for RateWeight
impl From<EntryRateWeight> for RateWeight
Sourcefn from(w: EntryRateWeight) -> RateWeight
fn from(w: EntryRateWeight) -> RateWeight
Converts to this type from the input type.
Sourceimpl Hash for RateWeight
impl Hash for RateWeight
Sourceimpl Ord for RateWeight
impl Ord for RateWeight
Sourcefn cmp(&self, other: &RateWeight) -> Ordering
fn cmp(&self, other: &RateWeight) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RateWeight
impl PartialEq for RateWeight
Sourceimpl PartialOrd for RateWeight
impl PartialOrd for RateWeight
Sourceimpl Serialize for RateWeight
impl Serialize for RateWeight
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<&RateWeight> for SerializedBytes
impl TryFrom<&RateWeight> for SerializedBytes
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(t: &RateWeight) -> Result<SerializedBytes, SerializedBytesError>
fn try_from(t: &RateWeight) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
Sourceimpl TryFrom<RateWeight> for SerializedBytes
impl TryFrom<RateWeight> for SerializedBytes
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(t: RateWeight) -> Result<SerializedBytes, SerializedBytesError>
fn try_from(t: RateWeight) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
Sourceimpl TryFrom<SerializedBytes> for RateWeight
impl TryFrom<SerializedBytes> for RateWeight
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(sb: SerializedBytes) -> Result<RateWeight, SerializedBytesError>
fn try_from(sb: SerializedBytes) -> Result<RateWeight, SerializedBytesError>
Performs the conversion.
impl Eq for RateWeight
impl StructuralPartialEq for RateWeight