ZomeCallParams

Struct ZomeCallParams 

pub struct ZomeCallParams {
    pub provenance: HoloHash<Agent>,
    pub cell_id: CellId,
    pub zome_name: ZomeName,
    pub fn_name: FunctionName,
    pub cap_secret: Option<CapSecret>,
    pub payload: ExternIO,
    pub nonce: Nonce256Bits,
    pub expires_at: Timestamp,
}
Zome calls need to be signed regardless of how they are called. This defines exactly what needs to be signed.

Fields

provenance: HoloHash<Agent>

Provenance to sign.

cell_id: CellId

Cell ID to sign.

zome_name: ZomeName

Zome name to sign.

fn_name: FunctionName

Function name to sign.

cap_secret: Option<CapSecret>

Cap secret to sign.

payload: ExternIO

Payload to sign.

nonce: Nonce256Bits

Nonce to sign.

expires_at: Timestamp

Time after which this zome call MUST NOT be accepted.

Implementations

Source

impl ZomeCallParams

pub fn serialize_and_hash( &self, ) -> Result<(Vec<u8>, Vec<u8>), SerializedBytesError>

Prepare the canonical bytes for zome call parameters so that they are always signed and verified in the same way. Signature is generated for the hash of the bytes.