EnableCloneCellInput

Type Alias EnableCloneCellInput 

pub type EnableCloneCellInput = DisableCloneCellInput;
Arguments to specify the clone cell to be enabled.

Aliased Type

pub struct EnableCloneCellInput {
    pub clone_cell_id: CloneCellId,
}

Fields

clone_cell_id: CloneCellId

The clone id or cell id of the clone cell