pub struct AgentActivityStatus {
pub valid_activity: Vec<(u32, HoloHash<Action>)>,
pub rejected_activity: Vec<(u32, HoloHash<Action>)>,
pub status: ChainStatus,
pub highest_observed: Option<HighestObserved>,
pub warrants: Vec<Signed<Warrant>>,
}Expand description
An agent’s status and chain records returned from a hdk::chain::get_agent_activity
query.
Fields
valid_activity: Vec<(u32, HoloHash<Action>)>Actions on this chain seen as valid by this authority, matching the
filters passed to the query, as a vector of
(action_sequence, action_hash) tuples.
Note: This may include actions seen as invalid by authorities
who have validated other DHT operations for the actions. Check the
AgentActivityStatus::warrants field for warrants against any of these
actions for a full picture of their validity.
rejected_activity: Vec<(u32, HoloHash<Action>)>Actions on this chain seen as invalid by this authority, matching the
filters passed to the query, as a vector of
(action_sequence, action_hash) tuples.
status: ChainStatusThe current status of this chain including details about the current
chain head, last valid action, and any forks, irrespective of
what chain actions match the filters. Note: warrants received from
other sources are not reflected in this status; check the value of the
AgentActivityStatus::warrants field.
highest_observed: Option<HighestObserved>The highest chain action that has been observed by this authority, irrespective of the filters. This includes actions that have been received by the authority but not yet validated or integrated.
warrants: Vec<Signed<Warrant>>Warrants collected for this agent. These warrants may be produced by various authorities around the DHT when they discover invalid DHT operations produced by the agent; they have been published to this authority as part of their responsibility to keep track of the agent’s status.