pub struct ZomeCallParams {
pub provenance: HoloHash<Agent>,
pub cell_id: CellId,
pub zome_name: ZomeName,
pub fn_name: FunctionName,
pub cap_secret: Option<CapSecret>,
pub payload: ExternIO,
pub nonce: Nonce256Bits,
pub expires_at: Timestamp,
}Expand description
Zome calls need to be signed regardless of how they are called. This defines exactly what needs to be signed.
Fields
provenance: HoloHash<Agent>Provenance to sign.
cell_id: CellIdCell ID to sign.
zome_name: ZomeNameZome name to sign.
fn_name: FunctionNameFunction name to sign.
cap_secret: Option<CapSecret>Cap secret to sign.
payload: ExternIOPayload to sign.
nonce: Nonce256BitsNonce to sign.
expires_at: TimestampTime after which this zome call MUST NOT be accepted.
Implementations
Sourceimpl ZomeCallParams
impl ZomeCallParams
Sourcepub fn serialize_and_hash(
&self,
) -> Result<(Vec<u8>, Vec<u8>), SerializedBytesError>
pub fn serialize_and_hash( &self, ) -> Result<(Vec<u8>, Vec<u8>), SerializedBytesError>
Prepare the canonical bytes for zome call parameters so that they are always signed and verified in the same way. Signature is generated for the hash of the bytes.