pub type EnableCloneCellInput = DisableCloneCellInput;Expand description
Arguments to specify the clone cell to be enabled.
Aliased Type
pub struct EnableCloneCellInput {
pub clone_cell_id: CloneCellId,
}Fields
clone_cell_id: CloneCellIdThe clone id or cell id of the clone cell